@@ -1,14 +1,15 @@
 from pydantic import BaseModel, Field, root_validator
-from caseconverter import camelcase
+from caseconverter import camelcase #type: ignore
 from typing import Any, Optional, Dict
 import typing
+# import deeplabel.client
 
 # import deeplabel.client
 
 class MixinConfig(BaseModel):
     class Config:
         allow_population_by_field_name = True
-        alias_generator = camelcase
+        alias_generator = camelcase # type: ignore
         arbitrary_types_allowed = True
 
 
