@@ -28,21 +28,21 @@ class Image(DeeplabelBase):
     project_id: str
 
     @classmethod
-    def _from_search_params(
+    def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
     ) -> List["Image"]:
         resp = client.get("/projects/gallery/images", params=params)
         images = resp.json()["data"]["images"]
         images = [cls(**image, client=client) for image in images]
-        return images
+        return images  # type: ignore
     
     @classmethod
     def from_gallery_id(cls, gallery_id:str, client:"deeplabel.client.BaseClient")->List["Image"]:
-        return cls._from_search_params({"galleryId":gallery_id}, client=client)
+        return cls.from_search_params({"galleryId":gallery_id}, client=client)
     
     @classmethod
     def from_image_id(cls, image_id: str, client: "deeplabel.client.BaseClient"):
-        images = cls._from_search_params({"imageId": image_id}, client)
+        images = cls.from_search_params({"imageId": image_id}, client)
         if not len(images):
             raise InvalidIdError(
                 f"Failed to fetch image with imageId  : {image_id}"
@@ -60,13 +60,13 @@ class Image(DeeplabelBase):
             "imageId":self.image_id,
             "projectId":self.project_id
             }
-            if d.type == ImageDetectionType.bounding_box:
+            if d.type == ImageDetectionType.bounding_box and d.bounding_box is not None:
                 detection['boundingBox'] = d.bounding_box.dict()
                 detection['type']='bounding_box'
-            if d.type == ImageDetectionType.polygon:
+            if d.type == ImageDetectionType.polygon and d.polygon is not None:
                 detection['type']='polygon'
                 detection['polygon'] = d.polygon.dict()
-            final_detections.append(detection)
+            final_detections.append(detection) #type: ignore
         self.client:"deeplabel.client.BaseClient"
         resp = self.client.post("/projects/gallery/images/detections/mixed", {"imageId":self.image_id, "insertData":final_detections, "deleteData":[],"updateData":[]})
         assert resp.status_code == 200, f"Failed to insert detections in deeplabel for imageId {self.image_id}. {resp.text}"
