@@ -11,9 +11,9 @@ from deeplabel.label.labels import DetectionLabel
 
 
 class DetectionType(Enum):
-    bounding_box = "bounding_box"
-    polygon = "polygon"
-    classification = "classification"
+    BOUNDING_BOX = "bounding_box"
+    POLYGON = "polygon"
+    CLASSIFICATION = "classification"
 
 
 class Detection(DeeplabelBase):
@@ -29,7 +29,7 @@ class Detection(DeeplabelBase):
     sequence_id:Optional[str]
 
     @classmethod
-    def _from_search_params(
+    def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
     ) -> List["Detection"]:
         """Make a get request for detections using the passed params. This
@@ -58,7 +58,7 @@ class Detection(DeeplabelBase):
         Returns:
             Detection: returns a Detection object or raises InvalidIdError if not found
         """
-        detections = cls._from_search_params({"detectionId": detection_id}, client)
+        detections = cls.from_search_params({"detectionId": detection_id}, client)
         if not len(detections):
             raise InvalidIdError(
                 f"Failed to fetch detections with detectionId  : {detection_id}"
@@ -75,4 +75,4 @@ class Detection(DeeplabelBase):
         Returns:
             List[Detection]: List of detections for the given videoTaskId
         """
-        return cls._from_search_params({"videoId": video_id, 'limit':'-1'}, client)
\ No newline at end of file
+        return cls.from_search_params({"videoId": video_id, 'limit':'-1'}, client)
\ No newline at end of file
