@@ -85,3 +85,11 @@ class BoundingBox(BaseModel):
 class BoundingBoxWithNumber(BoundingBox):
     """BoundingBox with number attribute for inference boundingBoxes"""
     number: Optional[int] = Field(default_factory=lambda:randint(0,2147483647))
+
+    def without_number(self):
+        return BoundingBox(
+            xmin = self.xmin,
+            ymin = self.ymin,
+            xmax = self.xmin,
+            ymax = self.ymax
+        )
